==> knetfilter_2.2.0.orig.tar.gz: knetfilter-2.2.0/src/knat.h <==
  /*

  knetfilter v. 2.2.0

  Copyright (C) 2001 Luigi Genoni
  		     venom@DarkStar.sns.it
  */


#ifndef KNETFILTER_H
#define KNETFILTER_H

#include <qlistbox.h>
#include <qpopupmenu.h>
#include <qpushbutton.h>
#include <qcombobox.h>
#include <qlineedit.h>
#include <qwidget.h>
#include <qmenubar.h>
#include <qmessagebox.h>
#include <qcheckbox.h>

#include <kapp.h>
#include <ktmainwindow.h>
#include <kpopupmenu.h>
#include <klocale.h>
#include <kprocess.h>
#include <kstatusbar.h>

#include "knat_gui.h"
#include "knat_debug.h"

#define PROGRAM_NAME	"knetfilter"


#define ID_HINTTEXT 1

class knetfilter : public KTMainWindow
{

  Q_OBJECT

protected:
  /* setup functions */
  void setupMenuBar();
  void setupToolBar();
  void setupStatusBar();
  void setupknetfilterWidget(); 

  void setupConnect();

  /* check for iptables function */
  void checkIptables();

  /* check for masqurading function */
  void checkMasquerade();

public:
  knetfilter( QWidget *parent=0, const char *name=0 );
  ~knetfilter();

  void closeEvent (QCloseEvent *);

  /* defines some processes */
  KProcess addp;
  KProcess addp2;
  KProcess addp3;
  KProcess delp;
  KProcess delp2;
  KProcess delp3;
  KProcess save;
  KProcess load;
  KProcess stop;
  KProcess setmark;
  KProcess markaddp;
  KProcess markdelp;
  KProcess stop_nat;
  KProcess stop_mangle;
  KProcess polrules;
  KProcess natpolrules;
  KProcess natrules;
  KProcess masqon; 
  KProcess masqoff; 
  KProcess rules;
  KProcess fetchIp;
  KProcess fetchNetmask;
  KProcess entries;
  KProcess tcpdump;
  KProcess stopdump;
  KProcess nmap;
  KProcess stopmap;
  KProcess addredirect;
  KProcess delredirect;
  KProcess addmangle;
  KProcess delmangle;
  KProcess manglepolrules;
  KProcess tcpmssrules;
  // KProcess stop_tcpmssrules;
  KProcess addshaperqdisc;
  KProcess addshaperrootclass;
  KProcess addshapersubclass;
  KProcess addshaperfilter;

public slots:
  void addRule();
  void delRule();
  void addRule_tcp();
  void delRule_tcp();
  void addRule_udp();
  void delRule_udp();
  void addRule_icmp();
  void delRule_icmp();
  void stopAll();
  void saveAll();
  void loadAll();
  void stopNAT();
  void stopMangle();
  void slotExit();
  void addDone_tcp();
  void delDone_tcp();
  void addDone_udp();
  void delDone_udp();
  void addDone_icmp();
  void delDone_icmp();
  void saveDone();
  void loadDone();
  void stopDone();
  void clearLog();


  /* list mark rules functions */
  void markRules();
  void addmarkRule();
  void delmarkRule();
  void setmarkRules(KProcess *, char *, int);
  void closemarkRules();
  void addmarkDone();
  void delmarkDone();
  void markchainActivated(int);
  void markpolicyActivated(int);
  void markstateActivated(int);

  /* interface functions */
  void startprobeInterface();
  void probeInterface(KProcess *, char *, int);
  void probeInterface2(KProcess *, char *, int); 
  void probeInterfaceDone();
  void starttcpDump();
  void stoptcpDump();
  void closetcpDump();
  void tcpDump();
  void listDump(KProcess *, char *, int);
  void startNMap();
  void stopNMap();
  void closeNMap();
  void nmapoptActivated(int);
  void nmapoptActivated_icmp(int);
  void NMap();
  void portDump(KProcess *, char *, int);

  /* list rules functions */
  void iptablesRules();
  void closeiptablesRules();
  void startlistRules();
  void listRulesDone();
  void listRules(KProcess *, char *, int);
  void interfaceActivated(int);
  void interfacenrActivated(int);
  void stateActivated(int);
  void chainActivated(int);
  void policyActivated(int);
  void flagsActivated(int);
  void polchainActivated(int);

  /* traffic shaper functions */
  void trafficShaper();
  void closeshaperRules();
  void startshaperRules();
  void shaperRules(KProcess *, char *, int);
  void shaperinterfaceActivated(int);
  void shaperinterfacenrActivated(int);
  void shaperQdisc();
  void shaperClass();
  void shaperSubclass();


  /* chain policy options */
  void polRules();
  void closepolRules();
  void startpolRules();
  void polRulesDone();
  void setpolRules(KProcess *, char *, int);
  void chainpolicyActivated(int);


  /* nat redirections options */
  void natRules();
  void closenatRules();
  void startnatRules();
  void stopnatRules();
  void stop_natDone();
  void setnatRules(KProcess *, char *, int);
  void natchainActivated(int);
  void natprotocolActivated(int);


  /* nat chain policy options */
  void natpolRules();
  void closenatpolRules();
  void startnatpolRules();
  void natpolRulesDone();
  void natpolchainActivated(int);
  void setnatpolRules(KProcess *, char *, int);
  void natpolicyActivated(int);
  

   /* list masq functions */
  void masqRules();
  void closemasqRules();
  void startmasqRules();
  void stopmasqRules();
  void masqonDone();
  void masqoffDone();
  void setmasqRules(KProcess *, char *, int);
  void masqinterfaceActivated(int);
  void masqinterfacenrActivated(int);
  void masqprotocolActivated(int);
  void startmasqEntries();
  void userEntries(KProcess *, char *, int);
  void userEntriesDone();


  /* list mangle functions */
  void mangleRules();
  void manglepolRules();
  void closemangleRules();
  void closemanglepolRules();
  void startmangleRules();
  void startmanglepolRules();
  void stopmangleRules();
  void manglepolRulesDone();
  void startmangleEntries();
  void stop_mangleDone();
  void setmangleRules(KProcess *, char *, int);
  void setmanglepolRules(KProcess *, char *, int);
  void mangleprotocolActivated(int);
  void manglechainActivated(int);
  void mangletosActivated(int);
  void manglepolchainActivated(int);
  void mangleactionActivated(int);
  void manglepolicyActivated(int); 
  void manglelogLevel(int);
  void log1Mode();
  void log2Mode();
  void log3Mode();

  /* list tcpmss options */
  void tcpmssRules();
  void closetcpmssRules();
  void starttcpmssRules();
  // void stoptcpmssRules();
  void tcpmssRulesDone();
  // void stop_tcpmssRulesDone(); 
  void settcpmssRules(KProcess *, char *, int);
  void tcpmssActivated(int);

private:
  /* some global objects */
  QPushButton *startBtn;
  QPushButton *stopBtn;
  QPushButton *helpBtn;
  QPushButton *exitBtn; 
  QListBox *messageLog;
  QPopupMenu *file;
  QPopupMenu *tables;
  QPopupMenu *nat_tables;
  QPopupMenu *mangle;
  QPopupMenu *options;
  QPopupMenu *help;
  QLineEdit *ipAddr;
  QLineEdit *netmaskAddr;
  QLineEdit *addSourcePort;
  QLineEdit *addDestinationPort;
  QLineEdit *addIcmpType;
  QLineEdit *addRuleNumber;
  QLineEdit *extraNet;
  QLineEdit *extraNetMask;
  QLineEdit *firstNet;
  QLineEdit *firstNetMask;
  QLineEdit *firstPort;
  QLineEdit *secondNet;
  QLineEdit *secondNetMask;
  QLineEdit *secondPort;
  QLineEdit *thirdNet;
  QLineEdit *thirdNetMask;
  QLineEdit *thirdPort;
  QLineEdit *markNumber;
  QLineEdit *markRuleNumber;
  QLineEdit *addnatRuleNumber;
  QLineEdit *addmasqRuleNumber;
  QLineEdit *masqSPortNumber;
  QLineEdit *masqDPortNumber;
  QLineEdit *firstmasqNet;
  QLineEdit *firstmasqNetMask;
  QLineEdit *secondmasqNet;
  QLineEdit *secondmasqNetMask;
  QLineEdit *addmangleSourcePort;
  QLineEdit *addmangleDestinationPort;
  QLineEdit *addmangleRuleNumber;
  QLineEdit *firstmangleNet;
  QLineEdit *firstmangleNetMask;
  QLineEdit *firstmanglePort;
  QLineEdit *secondmangleNet;
  QLineEdit *secondmangleNetMask;
  QLineEdit *secondmanglePort;
  QLineEdit *mangleMark;
  QLineEdit *logName;
  QLineEdit *mapNet;
  QLineEdit *mapNetMask;
  QLineEdit *addtcpmssRuleNumber;
  QLineEdit *firsttcpmssNet;
  QLineEdit *firsttcpmssNetMask;
  QLineEdit *secondtcpmssNet;
  QLineEdit *secondtcpmssNetMask;
  QLineEdit *shaperMark;
  QLineEdit *shaperglobalBand;
  QLineEdit *shaperrateBand;
  QLineEdit *shaperqdiscHandle;
  QLineEdit *shaperrootclassId;
  QLineEdit *shaperrootclassWeight;
  QLineEdit *shaperrootclassPrio;
  QLineEdit *shapersubclassId;
  QLineEdit *shapersubclassWeight;
  QLineEdit *shapersubclassPrio;

  KNFWidget *polList;
  KNFWidget *markList;
  KNFWidget *natList;
  KNFWidget *natpolList;
  KNFWidget *masqList;
  KNFWidget *mangleList;
  KNFWidget *manglepolList;
  KNFWidget *dumpList;
  KNFWidget *mapList;
  KNFWidget *masqWin;
  KNFWidget *tcpmssList;
  KNFWidget *shaperList;
  QListBox *polBox;
  QListBox *natpolBox;
  QListBox *manglepolBox;
  QListBox *masqBox;
  QListBox *dumpBox;
  QListBox *mapBox;
  QListBox *shaperBox;
  QComboBox *interface;
  QComboBox *interfacenr;
  QComboBox *chain;
  QComboBox *policy;
  QComboBox *markchain;
  QComboBox *markpolicy;
  QComboBox *markflags;
  QComboBox *markstate;
  QComboBox *nat;
  QComboBox *natinterface;
  QComboBox *natinterfacenr;
  QComboBox *natprotocol;
  QComboBox *masqinterface;
  QComboBox *masqinterfacenr;
  QComboBox *masqprotocol;
  QComboBox *flags;
  QComboBox *state;
  QComboBox *polchain;
  QComboBox *polchainpolicy;
  QComboBox *natchain;
  QComboBox *natchainpolicy;
  QComboBox *natpolchain;
  QComboBox *natpolchainpolicy;
  QComboBox *manglechain;
  QComboBox *manglechainpolicy;
  QComboBox *manglepolchain;
  QComboBox *manglepolchainpolicy;
  QComboBox *mangleprotocol;
  QComboBox *mangleaction;
  QComboBox *mangletos;
  QComboBox *loglevel;
  QComboBox *nmapoptions;
  QComboBox *nmapoptions_icmp;
  QComboBox *tcpmsschain;
  QComboBox *shaperinterface;
  QComboBox *shaperinterfacenr;
  QCheckBox *manglelog1;
  QCheckBox *manglelog2;
  QCheckBox *manglelog3;
  QCheckBox *shaperqdisc;
  QCheckBox *shaperclass;
  QCheckBox *shapersubclass;

  /* the menubar, toolbar statusbar and marktoolbar*/
  KMenuBar *menubar;
  KToolBar *toolbar;
  KStatusBar *statusbar;

  QWidget *masqWidget;

  /* checking for files */
  FILE *sbin;
  FILE *ip_masquerade;
  
  int toolbar1;
	
  int useMasq;
  char *use;
	
  char *interfaceChoice;
  int interfacenrChoice;
  char *interfaceChoicedmp;
  char *interfacenrChoicedmp;
  char *interfaceChoicemasq;
  char *ruleaction;
  char *chainChoice;
  char *state_modules;
  char *state_definition;
  char *stateChoice;
  char *policyChoice;
  char *flagChoice;
  char *markruleaction;
  char *markchainChoice;
  char *markpolicyChoice;
  char *markflagChoice;
  char *markstate_modules;
  char *markstate_definition;
  char *markstateChoice; 
  char *natprotocolChoice;
  char *polchainChoice;
  char *chainpolicyChoice;
  char *natruleaction;
  char *natchainChoice;
  char *natchainResult;
  char *natpolchainChoice;
  char *natchainpolicyChoice;
  char *masqinterfaceChoice;
  int masqinterfacenrChoice;
  char *masqinterfacenrChoicedmp;
  char *masqruleaction;
  char *masqprotocolChoice;
  char *manglechainChoice;
  char *manglepolchainChoice;
  char *mangleactionChoice;
  char *manglechainpolicyChoice;
  char *mangleprotocolChoice;
  char *mangletosChoice;
  char *mangleruleaction;
  char *mangleSyn;
  char *nmapopt;
  char *nmapopt_icmp;
  char *logLevel;
  char *log1;
  char *log2;
  char *log3;
  char *tcpmssChoice;
  char *tcpmssruleaction;
  char *shaperinterfaceChoice;
  int shaperinterfacenrChoice;
  char *shaperinterfaceChoicedmp;
  char *shaperinterfacenrChoicedmp;
  int qdisc_exec;
  int class_exec;
  int subclass_exec;

  // for the toolbar
  int add;
  int del; 

  int system_has_tc;
/*-------- REMOVE LATER --------
  int polcheck;
  int rulecheck;
  int dumpcheck;
  int natpolcheck;
  int natcheck;
  int masqcheck;
  ------------------------------*/

};

#endif

==> knetfilter_3.1.1.orig.tar.gz: knetfilter-3.1.1/src/knat.h <==
  /*

  knetfilter v. 3.0.2

  Copyright (C) 2002 Luigi Genoni
  		     venom@sns.it
  */


#ifndef KNETFILTER_H
#define KNETFILTER_H

#include <qlistbox.h>
#include <qpopupmenu.h>
#include <qpushbutton.h>
#include <qcombobox.h>
#include <qlineedit.h>
#include <qwidget.h>
#include <qmenubar.h>
#include <qmessagebox.h>
#include <qcheckbox.h>

#include <kapp.h>
#include <kmainwindow.h>
#include <kpopupmenu.h>
#include <klocale.h>
#include <kprocess.h>
#include <kstatusbar.h>

#include "knat_gui.h"
#include "knat_debug.h"

#define PROGRAM_NAME	"knetfilter"


#define ID_HINTTEXT 1

class knetfilter : public KMainWindow
{

  Q_OBJECT

protected:
  /* setup functions */
  void setupMenuBar();
  void setupToolBar();
  void setupStatusBar();
  void setupknetfilterWidget(); 

  void setupConnect();

  /* check for iptables function */
  void checkIptables();

  /* check for masqurading function */
  void checkMasquerade();

public:
  knetfilter( QWidget *parent=0, const char *name=0 );
  ~knetfilter();

  void closeEvent (QCloseEvent *);

  /* defines some processes */
  KProcess addp;
  KProcess addp2;
  KProcess addp3;
  KProcess delp;
  KProcess delp2;
  KProcess delp3;
  KProcess save;
  KProcess load;
  KProcess stop;
  KProcess setmark;
  KProcess markaddp;
  KProcess markdelp;
  KProcess stop_nat;
  KProcess stop_mangle;
  KProcess polrules;
  KProcess natpolrules;
  KProcess natrules;
  KProcess masqon; 
  KProcess masqoff; 
  KProcess rules;
  KProcess fetchIp;
  KProcess fetchNetmask;
  KProcess entries;
  KProcess routes;
  KProcess addr;
  KProcess routecache;
  KProcess tcpdump;
  KProcess stopdump;
  KProcess nmap;
  KProcess stopmap;
  KProcess addredirect;
  KProcess delredirect;
  KProcess addmangle;
  KProcess delmangle;
  KProcess manglepolrules;
  KProcess tcpmssrules;
  // KProcess stop_tcpmssrules;
  KProcess addshaperqdisc;
  KProcess addshaperrootclass;
  KProcess addshapersubclass;
  KProcess addshaperfilter;
  KProcess delshaperqdisc;
  KProcess delshaperrootclass;
  KProcess delshapersubclass;
  KProcess delshaperfilter;
  KProcess showqdisc;
  KProcess showclass;
  KProcess showfilter; 
  KProcess showip;

public slots:
  void addRule();
  void delRule();
  void addRule_tcp();
  void delRule_tcp();
  void addRule_udp();
  void delRule_udp();
  void addRule_icmp();
  void delRule_icmp();
  void stopAll();
  void saveAll();
  void loadAll();
  void stopNAT();
  void stopMangle();
  void slotExit();
  void addDone_tcp();
  void delDone_tcp();
  void addDone_udp();
  void delDone_udp();
  void addDone_icmp();
  void delDone_icmp();
  void saveDone();
  void loadDone();
  void stopDone();
  void clearLog();


  /* list mark rules functions */
  void markRules();
  void addmarkRule();
  void delmarkRule();
  void setmarkRules(KProcess *, char *, int);
  void closemarkRules();
  void addmarkDone();
  void delmarkDone();
  void markchainActivated(int);
  void markpolicyActivated(int);
  void markstateActivated(int);

  /* interface functions */
  void startprobeInterface();
  void probeInterface(KProcess *, char *, int);
  void probeInterface2(KProcess *, char *, int); 
  void probeInterfaceDone();
  void starttcpDump();
  void stoptcpDump();
  void closetcpDump();
  void tcpDump();
  void listDump(KProcess *, char *, int);
  void monitorResolver();
  void startNMap();
  void stopNMap();
  void closeNMap();
  void nmapoptActivated(int);
  void nmapoptActivated_icmp(int);
  void NMap();
  void portDump(KProcess *, char *, int);


  /* list rules functions */
  void iptablesRules();
  void closeiptablesRules();
  void startlistRules();
  void listRulesDone();
  void listRules(KProcess *, char *, int);
  void interfaceActivated(int);
  void interfacenrActivated(int);
  void stateActivated(int);
  void chainActivated(int);
  void policyActivated(int);
  void flagsActivated(int);
  void ecnflagsActivated(int);
  void polchainActivated(int);


  /* list route functions */
  void routeRules();
  void closerouteRules();
  void startlistRoutes();
  void listRoutesDone();
  void startlistAddr();
  void listAddrDone();
  void startlistrouteCache();
  void listrouteCacheDone();
  void listRoutes(KProcess *, char *, int);
  


  /* traffic shaper functions */
  void trafficShaper();
  void closeshaperRules();
  void startshaperRules();
  void delshaperRules();
  void shaperRules(KProcess *, char *, int);
  void shaperinterfaceActivated(int);
  void shaperinterfacenrActivated(int);
  void shaperQdisc();
  void shaperClass();
  void shaperSubclass();
  void trafficShaperMonitor();
  void closeshaperMonitor();
  void startqdiscMonitor();
  void startclassMonitor();
  void startfilterMonitor();
  void shaperMonitor(KProcess *, char *, int);
  void shapermonitorinterfaceActivated(int);
  void shapermonitorinterfacenrActivated(int);

  /* chain policy options */
  void polRules();
  void closepolRules();
  void startpolRules();
  void polRulesDone();
  void setpolRules(KProcess *, char *, int);
  void chainpolicyActivated(int);


  /* nat redirections options */
  void natRules();
  void closenatRules();
  void startnatRules();
  void stopnatRules();
  void stop_natDone();
  void setnatRules(KProcess *, char *, int);
  void natchainActivated(int);
  void natprotocolActivated(int);


  /* nat chain policy options */
  void natpolRules();
  void closenatpolRules();
  void startnatpolRules();
  void natpolRulesDone();
  void natpolchainActivated(int);
  void setnatpolRules(KProcess *, char *, int);
  void natpolicyActivated(int);
  

   /* list masq functions */
  void masqRules();
  void closemasqRules();
  void startmasqRules();
  void stopmasqRules();
  void masqonDone();
  void masqoffDone();
  void setmasqRules(KProcess *, char *, int);
  void masqinterfaceActivated(int);
  void masqinterfacenrActivated(int);
  void masqprotocolActivated(int);
  void startmasqEntries();
  void userEntries(KProcess *, char *, int);
  void userEntriesDone();


  /* list mangle functions */
  void mangleRules();
  void manglepolRules();
  void closemangleRules();
  void closemanglepolRules();
  void startmangleRules();
  void startmanglepolRules();
  void stopmangleRules();
  void manglepolRulesDone();
  void startmangleEntries();
  void stop_mangleDone();
  void setmangleRules(KProcess *, char *, int);
  void setmanglepolRules(KProcess *, char *, int);
  void mangleprotocolActivated(int);
  void manglechainActivated(int);
  void mangletosActivated(int);
  void manglepolchainActivated(int);
  void mangleactionActivated(int);
  void manglepolicyActivated(int); 
  void manglelogLevel(int);
  void log1Mode();
  void log2Mode();
  void log3Mode();

  /* list tcpmss options */
  void tcpmssRules();
  void closetcpmssRules();
  void starttcpmssRules();
  // void stoptcpmssRules();
  void tcpmssRulesDone();
  // void stop_tcpmssRulesDone(); 
  void settcpmssRules(KProcess *, char *, int);
  void tcpmssActivated(int);

private:
  /* some global objects */
  QPushButton *startBtn;
  QPushButton *stopBtn;
  QPushButton *helpBtn;
  QPushButton *exitBtn; 
  QListBox *messageLog;
  QPopupMenu *file;
  QPopupMenu *tables;
  QPopupMenu *nat_tables;
  QPopupMenu *mangle;
  QPopupMenu *options;
  QPopupMenu *help;
  QLineEdit *ipAddr;
  QLineEdit *netmaskAddr;
  QLineEdit *addSourcePort;
  QLineEdit *addDestinationPort;
  QLineEdit *addIcmpType;
  QLineEdit *addRuleNumber;
  QLineEdit *extraNet;
  QLineEdit *extraNetMask;
  QLineEdit *firstNet;
  QLineEdit *firstNetMask;
  QLineEdit *firstPort;
  QLineEdit *secondNet;
  QLineEdit *secondNetMask;
  QLineEdit *secondPort;
  QLineEdit *thirdNet;
  QLineEdit *thirdNetMask;
  QLineEdit *thirdPort;
  QLineEdit *markNumber;
  QLineEdit *markRuleNumber;
  QLineEdit *addnatRuleNumber;
  QLineEdit *addmasqRuleNumber;
  QLineEdit *masqSPortNumber;
  QLineEdit *masqDPortNumber;
  QLineEdit *firstmasqNet;
  QLineEdit *firstmasqNetMask;
  QLineEdit *secondmasqNet;
  QLineEdit *secondmasqNetMask;
  QLineEdit *addmangleSourcePort;
  QLineEdit *addmangleDestinationPort;
  QLineEdit *addmangleRuleNumber;
  QLineEdit *firstmangleNet;
  QLineEdit *firstmangleNetMask;
  QLineEdit *firstmanglePort;
  QLineEdit *secondmangleNet;
  QLineEdit *secondmangleNetMask;
  QLineEdit *secondmanglePort;
  QLineEdit *mangleMark;
  QLineEdit *mangleDscp;
  QLineEdit *logName;
  QLineEdit *ulogNlgroup;
  QLineEdit *ulogCprange;
  QLineEdit *ulogName;
  //  QLineEdit *ulogQthreshold;
  QLineEdit *mapNet;
  QLineEdit *mapNetMask;
  QLineEdit *addtcpmssRuleNumber;
  QLineEdit *firsttcpmssNet;
  QLineEdit *firsttcpmssNetMask;
  QLineEdit *secondtcpmssNet;
  QLineEdit *secondtcpmssNetMask;
  QLineEdit *shaperMark;
  QLineEdit *shaperglobalBand;
  QLineEdit *shaperrateBand;
  QLineEdit *shaperqdiscHandle;
  QLineEdit *shaperrootclassId;
  QLineEdit *shaperrootclassWeight;
  QLineEdit *shaperrootclassPrio;
  QLineEdit *shapersubclassId;
  QLineEdit *shapersubclassWeight;
  QLineEdit *shapersubclassPrio;

  KNFWidget *polList;
  KNFWidget *routeList;
  KNFWidget *markList;
  KNFWidget *natList;
  KNFWidget *natpolList;
  KNFWidget *masqList;
  KNFWidget *mangleList;
  KNFWidget *manglepolList;
  KNFWidget *dumpList;
  KNFWidget *mapList;
  KNFWidget *masqWin;
  KNFWidget *tcpmssList;
  KNFWidget *shaperList;
  KNFWidget *shapermonList;
  QListBox *polBox;
  QListBox *natpolBox;
  QListBox *manglepolBox;
  QListBox *masqBox;
  QListBox *routeBox;
  QListBox *dumpBox;
  QListBox *mapBox;
  QListBox *shaperBox;
  QListBox *shapermonBox;
  QComboBox *interface;
  QComboBox *interfacenr;
  QComboBox *chain;
  QComboBox *policy;
  QComboBox *markchain;
  QComboBox *markpolicy;
  QComboBox *markflags;
  QComboBox *markstate;
  QComboBox *nat;
  QComboBox *natinterface;
  QComboBox *natinterfacenr;
  QComboBox *natprotocol;
  QComboBox *masqinterface;
  QComboBox *masqinterfacenr;
  QComboBox *masqprotocol;
  QComboBox *flags;
  QComboBox *ecnflags;
  QComboBox *state;
  QComboBox *polchain;
  QComboBox *polchainpolicy;
  QComboBox *natchain;
  QComboBox *natchainpolicy;
  QComboBox *natpolchain;
  QComboBox *natpolchainpolicy;
  QComboBox *manglechain;
  QComboBox *manglechainpolicy;
  QComboBox *manglepolchain;
  QComboBox *manglepolchainpolicy;
  QComboBox *mangleprotocol;
  QComboBox *mangleaction;
  QComboBox *mangletos;
  QComboBox *loglevel;
  QComboBox *nmapoptions;
  QComboBox *nmapoptions_icmp;
  QComboBox *tcpmsschain;
  QComboBox *shaperinterface;
  QComboBox *shaperinterfacenr;
  QComboBox *shapermoninterface;
  QComboBox *shapermoninterfacenr;  
  QCheckBox *rulesmonitor_resolver;
  QCheckBox *manglelog1;
  QCheckBox *manglelog2;
  QCheckBox *manglelog3;
  QCheckBox *shaperqdisc;
  QCheckBox *shaperclass;
  QCheckBox *shapersubclass;

  /* the menubar, toolbar statusbar and marktoolbar*/
  KMenuBar *menubar;
  KToolBar *toolbar;
  KStatusBar *statusbar;

  QWidget *masqWidget;

  /* checking for files */
  FILE *sbin;
  FILE *ip_masquerade;
  
  int toolbar1;
	
  int useMasq;
  char *use;
	
  char *interfaceChoice;
  int interfacenrChoice;
  char *interfaceChoicedmp;
  char *interfacenrChoicedmp;
  char *interfaceChoicemasq;
  char *ruleaction;
  char *chainChoice;
  char *state_modules;
  char *state_definition;
  char *stateChoice;
  char *policyChoice;
  char *flagChoice;
  char *ecnflagChoice;
  char *ecnParam;
  char *hasEcn;
  int monitor_resolution;
  char *markruleaction;
  char *markchainChoice;
  char *markpolicyChoice;
  char *markflagChoice;
  char *markstate_modules;
  char *markstate_definition;
  char *markstateChoice; 
  char *natprotocolChoice;
  char *polchainChoice;
  char *chainpolicyChoice;
  char *natruleaction;
  char *natchainChoice;
  char *natchainResult;
  char *natpolchainChoice;
  char *natchainpolicyChoice;
  char *masqinterfaceChoice;
  int masqinterfacenrChoice;
  char *masqinterfacenrChoicedmp;
  char *masqruleaction;
  char *masqprotocolChoice;
  char *manglechainChoice;
  char *manglepolchainChoice;
  char *mangleactionChoice;
  char *manglechainpolicyChoice;
  char *mangleprotocolChoice;
  char *mangletosChoice;
  char *mangledscpChoice;
  char *mangleruleaction;
  char *mangleSyn;
  char *nmapopt;
  char *nmapopt_icmp;
  char *logLevel;
  char *log1;
  char *log2;
  char *log3;
  char *tcpmssChoice;
  char *tcpmssruleaction;
  char *shaperinterfaceChoice;
  int shaperinterfacenrChoice;
  char *shaperinterfaceChoicedmp;
  char *shaperinterfacenrChoicedmp;
  char *shapermonitorinterfaceChoice;
  int shapermonitorinterfacenrChoice;
  char *shapermonitorinterfaceChoicedmp;
  char *shapermonitorinterfacenrChoicedmp;
  int qdisc_exec;
  int class_exec;
  int subclass_exec;

  // for the toolbar
  int add;
  int del; 

  int system_has_tc;
/*-------- REMOVE LATER --------
  int polcheck;
  int rulecheck;
  int dumpcheck;
  int natpolcheck;
  int natcheck;
  int masqcheck;
  ------------------------------*/

};

#endif
